@@ -11,12 +11,22 @@ class TaskScheduleStatus(TextChoices):
     CLOSED = 'C', '关闭'
     DONE = 'D', '已完成'
     TEST = 'T', '测试'
+    ERROR = 'E', '调度错误'
 
 
 class TaskScheduleType(TextChoices):
     CRONTAB = 'C', 'Crontab'
-    ONETIME = 'O', '一次性'
+    ONCE = 'O', '一次性'
     CONTINUOUS = 'S', '连续性'
+    TIMINGS = 'T', '指定时间'
+
+
+class ScheduleTimingType(TextChoices):
+    DAY = 'DAY', '按天'
+    WEEKDAY = 'WEEKDAY', '按周'
+    MONTHDAY = 'MONTHDAY', '按月'
+    YEAR = 'YEAR', "按年"
+    DATETIME = 'DATETIME', '自选日期'
 
 
 class TaskCallbackStatus(TextChoices):
