@@ -1,6 +1,11 @@
 from . import models
 from django_common_objects.serializers import CommonCategorySerializer, CommonTagSerializer
 from rest_framework import serializers
+from . import get_task_model, get_schedule_log_model
+
+
+TaskModel = get_task_model()
+TaskScheduleLogModel = get_schedule_log_model()
 
 
 class TaskSerializer(serializers.ModelSerializer):
@@ -13,15 +18,17 @@ class TaskSerializer(serializers.ModelSerializer):
             return self.__class__(obj.parent).data
 
     class Meta:
-        model = models.Task
+        model = TaskModel
         exclude = ('update_time', )
 
 
 class QueueTaskSerializer(TaskSerializer):
+    tags = None
 
     class Meta:
-        model = models.Task
-        fields = ('id', 'name', 'config', 'category', 'status', 'parent', )
+        model = TaskModel
+        # fields = ('id', 'name', 'config', 'category', 'status', 'parent', )
+        exclude = ('user', 'update_time', 'description', 'create_time')
 
 
 class TaskCallbackSerializer(serializers.ModelSerializer):
@@ -47,12 +54,13 @@ class QueueScheduleSerializer(TaskScheduleSerializer):
 
     class Meta:
         model = models.TaskSchedule
-        fields = ('id', 'task', 'schedule_time', 'update_time', 'callback', 'user')
+        # fields = ('id', 'task', 'schedule_time', 'update_time', 'callback', 'user')
+        exclude = ('priority', 'create_time', 'schedule_start_time', 'schedule_end_time', 'config', 'status')
 
 
 class TaskScheduleLogSerializer(serializers.ModelSerializer):
-    schedule = TaskScheduleSerializer()
+    schedule = serializers.PrimaryKeyRelatedField(queryset=models.TaskSchedule.objects.all())
 
     class Meta:
-        model = models.TaskScheduleLog
-        exclude = ('update_time', )
+        model = TaskScheduleLogModel
+        fields = '__all__'
